@@ -17,6 +17,8 @@
 #include <QDomElement>
 #include <QFileDialog>
 #include <QTextCodec>
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 
 #include "qgisinterface.h"
 
@@ -34,6 +36,7 @@
 #include "qgsgrassmodule.h"
 #include "qgsgrassmoduleinput.h"
 #include "qgsgrassmoduleoptions.h"
+#include "moc_qgsgrassmoduleoptions.cpp"
 #include "qgsgrassmoduleparam.h"
 #include "qgsgrassplugin.h"
 
@@ -41,7 +44,8 @@
 
 QgsGrassModuleOptions::QgsGrassModuleOptions(
   QgsGrassTools *tools, QgsGrassModule *module,
-  QgisInterface *iface, bool direct )
+  QgisInterface *iface, bool direct
+)
   : mIface( iface )
   , mTools( tools )
   , mModule( module )
@@ -63,7 +67,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
   QgsGrassTools *tools, QgsGrassModule *module,
   QgisInterface *iface,
   QString xname, QDomElement confDocElem,
-  bool direct, QWidget *parent, Qt::WindowFlags f )
+  bool direct, QWidget *parent, Qt::WindowFlags f
+)
   : QWidget( parent, f )
   , QgsGrassModuleOptions( tools, module, iface, direct )
   , mXName( xname )
@@ -188,13 +193,12 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
           QString age = promptElem.attribute( QStringLiteral( "age" ) );
 
           //QgsDebugMsgLevel("element = " + element + " age = " + age, 3);
-          if ( age == QLatin1String( "old" ) && ( element == QLatin1String( "vector" ) || element == QLatin1String( "cell" ) ||
-                                                  element == QLatin1String( "strds" ) || element == QLatin1String( "stvds" ) ||
-                                                  element == QLatin1String( "str3ds" ) || element == QLatin1String( "stds" ) )
-               &&  confDomElement.attribute( QStringLiteral( "widget" ) ) != QLatin1String( "text" ) )
+          if ( age == QLatin1String( "old" ) && ( element == QLatin1String( "vector" ) || element == QLatin1String( "cell" ) || element == QLatin1String( "strds" ) || element == QLatin1String( "stvds" ) || element == QLatin1String( "str3ds" ) || element == QLatin1String( "stds" ) )
+               && confDomElement.attribute( QStringLiteral( "widget" ) ) != QLatin1String( "text" ) )
           {
             QgsGrassModuleInput *mi = new QgsGrassModuleInput(
-              mModule, this, key, confDomElement, descDocElem, gnode, mDirect, this );
+              mModule, this, key, confDomElement, descDocElem, gnode, mDirect, this
+            );
 
             layout->addWidget( mi );
             created = true;
@@ -205,7 +209,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
         if ( !created )
         {
           QgsGrassModuleOption *so = new QgsGrassModuleOption(
-            mModule, key, confDomElement, descDocElem, gnode, mDirect, this );
+            mModule, key, confDomElement, descDocElem, gnode, mDirect, this
+          );
 
           layout->addWidget( so );
           mParams.append( so );
@@ -231,7 +236,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
       {
         QgsGrassModuleGdalInput *mi = new QgsGrassModuleGdalInput(
           mModule, QgsGrassModuleGdalInput::Ogr, key, confDomElement,
-          descDocElem, gnode, mDirect, this );
+          descDocElem, gnode, mDirect, this
+        );
         layout->addWidget( mi );
         mParams.append( mi );
       }
@@ -239,7 +245,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
       {
         QgsGrassModuleGdalInput *mi = new QgsGrassModuleGdalInput(
           mModule, QgsGrassModuleGdalInput::Gdal, key, confDomElement,
-          descDocElem, gnode, mDirect, this );
+          descDocElem, gnode, mDirect, this
+        );
         layout->addWidget( mi );
         mParams.append( mi );
       }
@@ -249,7 +256,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
         {
           QgsGrassModuleVectorField *mi = new QgsGrassModuleVectorField(
             mModule, this, key, confDomElement,
-            descDocElem, gnode, mDirect, this );
+            descDocElem, gnode, mDirect, this
+          );
           layout->addWidget( mi );
           mParams.append( mi );
         }
@@ -257,7 +265,8 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
         {
           QgsGrassModuleField *mi = new QgsGrassModuleField(
             mModule, key, confDomElement,
-            descDocElem, gnode, mDirect, this );
+            descDocElem, gnode, mDirect, this
+          );
           layout->addWidget( mi );
           mParams.append( mi );
         }
@@ -266,21 +275,24 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
       {
         QgsGrassModuleSelection *mi = new QgsGrassModuleSelection(
           mModule, this, key, confDomElement,
-          descDocElem, gnode, mDirect, this );
+          descDocElem, gnode, mDirect, this
+        );
         layout->addWidget( mi );
         mParams.append( mi );
       }
       else if ( optionType == QLatin1String( "file" ) )
       {
         QgsGrassModuleFile *mi = new QgsGrassModuleFile(
-          mModule, key, confDomElement, descDocElem, gnode, mDirect, this );
+          mModule, key, confDomElement, descDocElem, gnode, mDirect, this
+        );
         layout->addWidget( mi );
         mParams.append( mi );
       }
       else if ( optionType == QLatin1String( "flag" ) )
       {
         QgsGrassModuleFlag *flag = new QgsGrassModuleFlag(
-          mModule, key, confDomElement, descDocElem, gnode, mDirect, this );
+          mModule, key, confDomElement, descDocElem, gnode, mDirect, this
+        );
 
         layout->addWidget( flag );
         mParams.append( flag );
@@ -369,7 +381,6 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
   {
     mErrors << item->errors();
   }
-
 }
 
 void QgsGrassModuleStandardOptions::switchAdvanced()
@@ -470,7 +481,7 @@ QList<QgsGrassProvider *> QgsGrassModuleStandardOptions::grassProviders()
     if ( layer->type() == Qgis::LayerType::Vector )
     {
       QgsVectorLayer *vector = qobject_cast<QgsVectorLayer *>( layer );
-      if ( vector  && vector->providerType() == QLatin1String( "grass" ) )
+      if ( vector && vector->providerType() == QLatin1String( "grass" ) )
       {
         QgsGrassProvider *provider = qobject_cast<QgsGrassProvider *>( vector->dataProvider() );
         if ( provider )
@@ -491,7 +502,7 @@ QList<QgsGrassRasterProvider *> QgsGrassModuleStandardOptions::grassRasterProvid
     if ( layer->type() == Qgis::LayerType::Raster )
     {
       QgsRasterLayer *raster = qobject_cast<QgsRasterLayer *>( layer );
-      if ( raster  && raster->providerType() == QLatin1String( "grassraster" ) )
+      if ( raster && raster->providerType() == QLatin1String( "grassraster" ) )
       {
         QgsGrassRasterProvider *provider = qobject_cast<QgsGrassRasterProvider *>( raster->dataProvider() );
         if ( provider )
@@ -670,7 +681,7 @@ QStringList QgsGrassModuleStandardOptions::checkRegion()
     if ( !item )
       continue;
 
-    QgsDebugMsgLevel( "currentMap = " +  item->currentMap(), 3 );
+    QgsDebugMsgLevel( "currentMap = " + item->currentMap(), 3 );
     // The input may be empty, it means input is not used.
 
     if ( item->currentMap().isEmpty() )
@@ -682,8 +693,7 @@ QStringList QgsGrassModuleStandardOptions::checkRegion()
       continue;
     }
 
-    if ( G_window_overlap( &currentWindow,
-                           window.north, window.south, window.east, window.west ) == 0 )
+    if ( G_window_overlap( &currentWindow, window.north, window.south, window.east, window.west ) == 0 )
     {
       list.append( item->currentMap() );
     }
@@ -757,7 +767,7 @@ bool QgsGrassModuleStandardOptions::inputRegion( struct Cell_head *window, QgsCo
         continue;
       }
 
-      QgsDebugMsgLevel( "currentMap = " +  item->currentMap(), 3 );
+      QgsDebugMsgLevel( "currentMap = " + item->currentMap(), 3 );
       // The input may be empty, it means input is not used.
       if ( item->currentMap().isEmpty() )
       {
@@ -798,7 +808,8 @@ bool QgsGrassModuleStandardOptions::requestsRegion()
 {
   QgsDebugMsgLevel( "called.", 4 );
 
-  if ( mDirect ) return true;
+  if ( mDirect )
+    return true;
 
   for ( int i = 0; i < mParams.size(); i++ )
   {
@@ -838,7 +849,7 @@ bool QgsGrassModuleStandardOptions::getCurrentMapRegion( QgsGrassModuleInput *in
     return false;
   }
 
-  QgsDebugMsgLevel( "currentMap = " +  input->currentMap(), 3 );
+  QgsDebugMsgLevel( "currentMap = " + input->currentMap(), 3 );
   if ( input->currentMap().isEmpty() )
   {
     // The input may be empty, it means input is not used.
@@ -852,10 +863,7 @@ bool QgsGrassModuleStandardOptions::getCurrentMapRegion( QgsGrassModuleInput *in
   {
     mapset = mm.value( 1 );
   }
-  if ( !QgsGrass::mapRegion( input->type(),
-                             QgsGrass::getDefaultGisdbase(),
-                             QgsGrass::getDefaultLocation(), mapset, map,
-                             window ) )
+  if ( !QgsGrass::mapRegion( input->type(), QgsGrass::getDefaultGisdbase(), QgsGrass::getDefaultLocation(), mapset, map, window ) )
   {
     QgsGrass::warning( tr( "Cannot get region of map %1" ).arg( input->currentMap() ) );
     return false;
@@ -896,8 +904,7 @@ QDomDocument QgsGrassModuleStandardOptions::readInterfaceDescription( const QStr
   if ( !process.waitForStarted()
        || !process.waitForReadyRead()
        || !process.waitForFinished()
-       || ( process.exitCode() != 0 && process.exitCode() != 255 &&
-            ( !cmd.endsWith( QLatin1String( ".py" ) ) || process.exitCode() != 1 ) ) )
+       || ( process.exitCode() != 0 && process.exitCode() != 255 && ( !cmd.endsWith( QLatin1String( ".py" ) ) || process.exitCode() != 1 ) ) )
   {
     QString pathVariable = QgsGrassModule::libraryPathVariable();
     QgsDebugError( "process.exitCode() = " + QString::number( process.exitCode() ) );
@@ -905,10 +912,7 @@ QDomDocument QgsGrassModuleStandardOptions::readInterfaceDescription( const QStr
                   + "<br><br>" + pathVariable + "=" + environment.value( pathVariable )
                   + "<br><br>PATH=" + environment.value( QStringLiteral( "PATH" ) )
                   + "<br><br>PYTHONPATH=" + environment.value( QStringLiteral( "PYTHONPATH" ) )
-                  + "<br><br>" + tr( "command" ) + QStringLiteral( ": %1 %2<br>%3<br>%4" )
-                  .arg( cmd, arguments.join( QLatin1Char( ' ' ) ),
-                        process.readAllStandardOutput().constData(),
-                        process.readAllStandardError().constData() );
+                  + "<br><br>" + tr( "command" ) + QStringLiteral( ": %1 %2<br>%3<br>%4" ).arg( cmd, arguments.join( QLatin1Char( ' ' ) ), process.readAllStandardOutput().constData(), process.readAllStandardError().constData() );
     QgsDebugError( msg );
     errors << msg;
     return gDoc;
@@ -928,10 +932,11 @@ QDomDocument QgsGrassModuleStandardOptions::readInterfaceDescription( const QStr
   // TODO: We should check the correct encoding by using the BOM (Byte
   // Order Mark) from the beginning of the data.
   QString xmlDeclaration = QString::fromUtf8( baDesc ).section( '>', 0, 0, QString::SectionIncludeTrailingSep );
-  QRegExp reg( "<\\?xml\\s+.*encoding\\s*=\\s*(['\"])([A-Za-z][-a-zA-Z0-9_.]*)\\1\\s*\\?>" );
-  if ( reg.indexIn( xmlDeclaration ) != -1 )
+  const thread_local QRegularExpression reg( "<\\?xml\\s+.*encoding\\s*=\\s*(['\"])([A-Za-z][-a-zA-Z0-9_.]*)\\1\\s*\\?>" );
+  const QRegularExpressionMatch match = reg.match( xmlDeclaration );
+  if ( match.hasMatch() )
   {
-    QByteArray enc = reg.cap( 2 ).toLocal8Bit();
+    QByteArray enc = match.captured( 2 ).toLocal8Bit();
     QgsDebugMsgLevel( QString( "found encoding name '%1'" ).arg( QString::fromUtf8( enc ) ), 3 );
 
     codec = QTextCodec::codecForName( enc );
